==> nextcloud-22.2.9.tgz: nextcloud/apps/files_sharing/l10n/es_AR.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Compartido con usted",
    "Nothing shared with you yet" : "Nada ha sido compartido aún con usted",
    "Files and folders others share with you will show up here" : "Los archivos y carpetas que sean compartidos con usted se mostrarán aquí",
    "Shared with others" : "Compartido con otros",
    "Nothing shared yet" : "Nada compartido aún",
    "Files and folders you share will show up here" : "Los archivos y carpetas que comparta se mostrarán aquí",
    "Shared by link" : "Compartido por link",
    "No shared links" : "No hay links compartidos",
    "Files and folders you share by link will show up here" : "Los archivos y carpetas que comparta por links se mostrarán aquí",
    "Shares" : "Shares",
    "Restore" : "Restaurar",
    "error" : "error",
    "Move or copy" : "Mover o Copiar",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "You can upload into this folder" : "Usted puede cargar archivos dentro de esta carpeta",
    "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
    "Invalid server URL" : "URL del servidor inválido",
    "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar el link público a su Nextcloud",
    "No expiration date set" : "No se ha establecido la fecha de expiración",
    "Shared by" : "Compartido por",
    "File shares" : "Archivos compartidos",
    "Downloaded via public link" : "Descargado mediante un link público",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado mediante una link público",
    "{email} downloaded {file}" : "{email} descargó {file}",
    "Shared with group {group}" : "Compartido con el gupo {group}",
    "Removed share for group {group}" : "Se eliminó el elemento compartido del grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartió con el grupo {group}",
    "{actor} removed share for group {group}" : "{actor} eliminó el elemento compartido del grupo {group}",
    "You shared {file} with group {group}" : "Usted ha compartido {file} con el grupo {group}",
    "You removed group {group} from {file}" : "Usted eliminó al grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartió {file} con el grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} lo eliminó del grupo {group} de {file}",
    "Shared as public link" : "Compartido como un link público",
    "Removed public link" : "Link público eliminado",
    "Public link expired" : "El link público ha expirado",
    "{actor} shared as public link" : "{actor} compartió como un link público",
    "{actor} removed public link" : "{actor} eliminó el link público",
    "Public link of {actor} expired" : "El link público de {actor} ha expirado",
    "You shared {file} as public link" : "Usted ha compartido {file} como un link público",
    "You removed public link for {file}" : "Usted ha eliminado el link público de {file}",
    "Public link expired for {file}" : "El link público para {file} ha expirado",
    "{actor} shared {file} as public link" : "{actor} ha compatido {file} como un link público",
    "{actor} removed public link for {file}" : "{actor} eliminó el link público de {file}",
    "Public link of {actor} for {file} expired" : "El link público de {actor} para {file} ha expirado",
    "{user} accepted the remote share" : "{user} aceptó el elemento compartido remoto",
    "{user} declined the remote share" : "{user} declinó el elemento compartido remoto",
    "You received a new remote share {file} from {user}" : "Usted ha recibido un nuevo elemento compartido remoto {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptó el elemento compartido remoto de {file}",
    "{user} declined the remote share of {file}" : "{user} declinó el elemento compartido remoto de {file}",
    "{user} unshared {file} from you" : "{user} ha dejado de compartir {file} con usted",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Eliminó el elemento compartido para {user}",
    "{actor} removed themselves" : "{actor} se ha eliminado",
    "{actor} shared with {user}" : "{actor} compartió con {user}",
    "{actor} removed share for {user}" : "{actor} eliminó el elemento compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} eliminó el elemento compartido",
    "You shared {file} with {user}" : "Usted ha compartido {file} con {user}",
    "You removed {user} from {file}" : "Usted eliminó a {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartió {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} eliminó a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} ha compartido {file} con usted",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un archivo o carpeta compartido por correo o por link público ha sido <strong>descargado</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un archivo o carpeta fue compartido desde <strong>otro servidor</strong>",
    "Files" : "Archivos",
    "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
    "Could not delete share" : "No fue posible borrar el elemento compartido",
    "Please specify a file or folder path" : "Favor de especificar un archivo o ruta de carpeta",
    "Could not create share" : "no fue posible crear el elemento compartido",
    "Please specify a valid user" : "Favor de especificar un usuario válido",
    "Group sharing is disabled by the administrator" : "Compartir en grupos está deshabilitado por el administrador",
    "Please specify a valid group" : "Favor de especificar un grupo valido",
    "Public link sharing is disabled by the administrator" : "Compartir links públicos está deshabilitado por el administrador",
    "Public upload disabled by the administrator" : "Cargas públicas deshabilitadas por el administrador",
    "Public upload is only possible for publicly shared folders" : "Las cargas públicas son posibles sólo para carpetas compartidas públicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Usted no puede compartir al Círculo si la aplicación no esta habilitada",
    "Please specify a valid circle" : "Favor de especificar un círculo válido",
    "Unknown share type" : "Tipo de elemento compartido desconocido",
    "Not a directory" : "No es una carpeta",
    "Could not lock path" : "No fue posible bloquear la ruta",
    "Wrong or no update parameter given" : "El parametro de actualización esta erróneo o faltante",
    "Direct link" : "Link directa",
    "Share API is disabled" : "El API para compartir está deshabilitado",
    "File sharing" : "Compartir archivos",
    "Accept" : "Aceptar",
    "Sharing" : "Compartiendo",
    "Reset" : "Restablecer",
    "Unknown error" : "Error desconocido",
    "Allow editing" : "Permitir edición",
    "Read only" : "Solo lectura",
    "Allow upload and editing" : "Permitir cargar y editar",
    "File drop (upload only)" : "Soltar archivo (solo para carga)",
    "Read" : "Leer",
    "Upload" : "Cargar",
    "Edit" : "Editar",
    "Allow creating" : "Permitir crear",
    "Allow deleting" : "Permitir borrar",
    "Allow resharing" : "Permitir volver a compartir",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Note to recipient" : "Nota al destinatario",
    "Unshare" : "No compartir",
    "group" : "grupo",
    "remote" : "remoto",
    "Link copied" : "Link copiado",
    "Cannot copy, please copy the link manually" : "No es posible copiar, por favor copia el enlace manualmente",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Only works for users with access to this folder" : "Solo funciona para usuarios con acceso a esta carpeta",
    "Password protection" : "Protección con contraseña",
    "Enter a password" : "Ingrese una contraseña",
    "Cancel" : "Cancelar",
    "Hide download" : "Ocultar descarga",
    "Password protect" : "Proteger con contraseña",
    "Add another link" : "Agregar otro enlace",
    "Share link" : "Compartir enlace",
    "No recommendations. Start typing." : "No hay sugerencias. Comenzar a escribir",
    "Resharing is not allowed" : "No está permitido volver a compartir",
    "Searching …" : "Buscando ...",
    "No elements found." : "No se encontraron elementos",
    "Shared with you by {owner}" : "Compartido con usted por {owner}",
    "Shared" : "Compartido",
    "Share" : "Compartir",
    "Shared with you and the group {group} by {owner}" : "Compartido con usted y el grupo {group} por {owner}",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Share time" : "Tiempo de compartir",
    "Expiration date" : "Fecha de expiración",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el link expiró",
    "sharing is disabled" : "compartir está deshabilitado",
    "For more info, please ask the person who sent this link." : "Para mayores informes, contacte a la persona que le envió este link.",
    "Share note" : "Compartir nota",
    "Toggle grid view" : "Vista de cuadrícula",
    "Upload files to %s" : "Cargar archivos a %s",
    "Note" : "Nota",
    "Select or drop files" : "Seleccione o suelte los archivos",
    "Uploaded files:" : "Archivos cargados:",
    "Add to your Nextcloud" : "Agregar a su Nextcloud",
    "Wrong share ID, share doesn't exist" : "ID del elemento compartido equivocado, el elemento compartido no existe",
    "Wrong path, file/folder doesn't exist" : "La ruta es incorrecta, el archivo/carpeta no existe",
    "Sorry, this link doesn’t seem to work anymore." : "Lo sentimos, este link no parece funcionar más. "
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-22.2.10.tgz: nextcloud/apps/files_sharing/l10n/es_AR.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Compartido con usted",
    "Nothing shared with you yet" : "Nada ha sido compartido aún con usted",
    "Files and folders others share with you will show up here" : "Los archivos y carpetas que sean compartidos con usted se mostrarán aquí",
    "Shared with others" : "Compartido con otros",
    "Nothing shared yet" : "Nada compartido aún",
    "Files and folders you share will show up here" : "Los archivos y carpetas que comparta se mostrarán aquí",
    "Shared by link" : "Compartido por link",
    "No shared links" : "No hay links compartidos",
    "Files and folders you share by link will show up here" : "Los archivos y carpetas que comparta por links se mostrarán aquí",
    "Shares" : "Shares",
    "Restore" : "Restaurar",
    "error" : "error",
    "Move or copy" : "Mover o Copiar",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "You can upload into this folder" : "Usted puede cargar archivos dentro de esta carpeta",
    "No compatible server found at {remote}" : "No se encontró un servidor compatible en {remote}",
    "Invalid server URL" : "URL del servidor inválido",
    "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar el link público a su Nextcloud",
    "No expiration date set" : "No se ha establecido la fecha de expiración",
    "Shared by" : "Compartido por",
    "File shares" : "Archivos compartidos",
    "Downloaded via public link" : "Descargado mediante un link público",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado mediante una link público",
    "{email} downloaded {file}" : "{email} descargó {file}",
    "Shared with group {group}" : "Compartido con el gupo {group}",
    "Removed share for group {group}" : "Se eliminó el elemento compartido del grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartió con el grupo {group}",
    "{actor} removed share for group {group}" : "{actor} eliminó el elemento compartido del grupo {group}",
    "You shared {file} with group {group}" : "Usted ha compartido {file} con el grupo {group}",
    "You removed group {group} from {file}" : "Usted eliminó al grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartió {file} con el grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} lo eliminó del grupo {group} de {file}",
    "Shared as public link" : "Compartido como un link público",
    "Removed public link" : "Link público eliminado",
    "Public link expired" : "El link público ha expirado",
    "{actor} shared as public link" : "{actor} compartió como un link público",
    "{actor} removed public link" : "{actor} eliminó el link público",
    "Public link of {actor} expired" : "El link público de {actor} ha expirado",
    "You shared {file} as public link" : "Usted ha compartido {file} como un link público",
    "You removed public link for {file}" : "Usted ha eliminado el link público de {file}",
    "Public link expired for {file}" : "El link público para {file} ha expirado",
    "{actor} shared {file} as public link" : "{actor} ha compatido {file} como un link público",
    "{actor} removed public link for {file}" : "{actor} eliminó el link público de {file}",
    "Public link of {actor} for {file} expired" : "El link público de {actor} para {file} ha expirado",
    "{user} accepted the remote share" : "{user} aceptó el elemento compartido remoto",
    "{user} declined the remote share" : "{user} declinó el elemento compartido remoto",
    "You received a new remote share {file} from {user}" : "Usted ha recibido un nuevo elemento compartido remoto {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptó el elemento compartido remoto de {file}",
    "{user} declined the remote share of {file}" : "{user} declinó el elemento compartido remoto de {file}",
    "{user} unshared {file} from you" : "{user} ha dejado de compartir {file} con usted",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Eliminó el elemento compartido para {user}",
    "{actor} removed themselves" : "{actor} se ha eliminado",
    "{actor} shared with {user}" : "{actor} compartió con {user}",
    "{actor} removed share for {user}" : "{actor} eliminó el elemento compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} eliminó el elemento compartido",
    "You shared {file} with {user}" : "Usted ha compartido {file} con {user}",
    "You removed {user} from {file}" : "Usted eliminó a {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartió {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} eliminó a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} ha compartido {file} con usted",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un archivo o carpeta compartido por correo o por link público ha sido <strong>descargado</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un archivo o carpeta fue compartido desde <strong>otro servidor</strong>",
    "Files" : "Archivos",
    "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
    "Could not delete share" : "No fue posible borrar el elemento compartido",
    "Please specify a file or folder path" : "Favor de especificar un archivo o ruta de carpeta",
    "Could not create share" : "no fue posible crear el elemento compartido",
    "Please specify a valid user" : "Favor de especificar un usuario válido",
    "Group sharing is disabled by the administrator" : "Compartir en grupos está deshabilitado por el administrador",
    "Please specify a valid group" : "Favor de especificar un grupo valido",
    "Public link sharing is disabled by the administrator" : "Compartir links públicos está deshabilitado por el administrador",
    "Public upload disabled by the administrator" : "Cargas públicas deshabilitadas por el administrador",
    "Public upload is only possible for publicly shared folders" : "Las cargas públicas son posibles sólo para carpetas compartidas públicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Usted no puede compartir al Círculo si la aplicación no esta habilitada",
    "Please specify a valid circle" : "Favor de especificar un círculo válido",
    "Unknown share type" : "Tipo de elemento compartido desconocido",
    "Not a directory" : "No es una carpeta",
    "Could not lock path" : "No fue posible bloquear la ruta",
    "Wrong or no update parameter given" : "El parametro de actualización esta erróneo o faltante",
    "Direct link" : "Link directa",
    "Share API is disabled" : "El API para compartir está deshabilitado",
    "File sharing" : "Compartir archivos",
    "Accept" : "Aceptar",
    "Sharing" : "Compartiendo",
    "Reset" : "Restablecer",
    "Unknown error" : "Error desconocido",
    "Allow editing" : "Permitir edición",
    "Read only" : "Solo lectura",
    "Allow upload and editing" : "Permitir cargar y editar",
    "File drop (upload only)" : "Soltar archivo (solo para carga)",
    "Read" : "Leer",
    "Upload" : "Cargar",
    "Edit" : "Editar",
    "Allow creating" : "Permitir crear",
    "Allow deleting" : "Permitir borrar",
    "Allow resharing" : "Permitir volver a compartir",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Note to recipient" : "Nota al destinatario",
    "Unshare" : "No compartir",
    "group" : "grupo",
    "remote" : "remoto",
    "Link copied" : "Link copiado",
    "Cannot copy, please copy the link manually" : "No es posible copiar, por favor copia el enlace manualmente",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Only works for users with access to this folder" : "Solo funciona para usuarios con acceso a esta carpeta",
    "Password protection" : "Protección con contraseña",
    "Enter a password" : "Ingrese una contraseña",
    "Cancel" : "Cancelar",
    "Hide download" : "Ocultar descarga",
    "Password protect" : "Proteger con contraseña",
    "Add another link" : "Agregar otro enlace",
    "Share link" : "Compartir enlace",
    "No recommendations. Start typing." : "No hay sugerencias. Comenzar a escribir",
    "Resharing is not allowed" : "No está permitido volver a compartir",
    "Searching …" : "Buscando ...",
    "No elements found." : "No se encontraron elementos",
    "Shared with you by {owner}" : "Compartido con usted por {owner}",
    "Shared" : "Compartido",
    "Share" : "Compartir",
    "Shared with you and the group {group} by {owner}" : "Compartido con usted y el grupo {group} por {owner}",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Share time" : "Tiempo de compartir",
    "Expiration date" : "Fecha de expiración",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el link expiró",
    "sharing is disabled" : "compartir está deshabilitado",
    "For more info, please ask the person who sent this link." : "Para mayores informes, contacte a la persona que le envió este link.",
    "Share note" : "Compartir nota",
    "Upload files to %s" : "Cargar archivos a %s",
    "Note" : "Nota",
    "Select or drop files" : "Seleccione o suelte los archivos",
    "Uploaded files:" : "Archivos cargados:",
    "Add to your Nextcloud" : "Agregar a su Nextcloud",
    "Wrong share ID, share doesn't exist" : "ID del elemento compartido equivocado, el elemento compartido no existe",
    "Wrong path, file/folder doesn't exist" : "La ruta es incorrecta, el archivo/carpeta no existe",
    "Sorry, this link doesn’t seem to work anymore." : "Lo sentimos, este link no parece funcionar más. ",
    "Toggle grid view" : "Vista de cuadrícula"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
